@@ -4,13 +4,10 @@ use v5.22;
 use strict;
 use warnings;
 
-use Try::Tiny::Tiny;
-
 use Moose;
-use MooseX::StrictConstructor;
 use MooseX::Aliases;
 use Carp;
-use Try::Catch;
+use Try::Tiny;
 use Time::Piece;
 use Time::Seconds;
 use Date::Advent;
@@ -27,11 +24,11 @@ Date::Lectionary::Day - Determines the Day in the Christian Liturgical Year
 
 =head1 VERSION
 
-Version 1.3.0
+Version 1.20161223
 
 =cut
 
-use version; our $VERSION = version->declare("v1.3.0");
+our $VERSION = '1.20161223';
 
 =head1 SYNOPSIS
 
@@ -42,7 +39,6 @@ A helper object for Date::Lectionary to determine the liturgical name(s) and typ
 enum 'DayType',        [qw(fixedFeast moveableFeast Sunday noLect)];
 enum 'LectionaryType', [qw(acna rcl)];
 enum 'MultiLect',      [qw(yes no)];
-enum 'IncludeFeasts',  [qw(yes no)];
 no Moose::Util::TypeConstraints;
 
 =head1 SUBROUTINES/METHODS/ATTRIBUTES
@@ -77,12 +73,6 @@ Returns 'yes' if the day has multiple services with readings associated with it.
 
 An ArrayRef of the names of the multiple services that occur on a multiLect day.
 
-=head3 includeFeasts
-
-If this is set to 'yes' --- the default value --- the module will include fixed and moveable feasts in its determination of which liturgical Sunday it is.
-
-If set to 'no', it will exclude fixed and moveable feasts.  Excluding feasts is useful when using Date::Lectionary::Day in combination with a daily lectionary such as Date::Lectioary::Daily where a fixed feast such as The Transfiguration can conflict with determining the Sunday to use for the daily lectionary.
-
 =cut
 
 has 'date' => (
@@ -141,12 +131,6 @@ has 'subLects' => (
     init_arg => undef,
 );
 
-has 'includeFeasts' => (
-    is      => 'ro',
-    isa     => 'IncludeFeasts',
-    default => 'yes',
-);
-
 =head2 BUILD
 
 Constructor for the Date::Lectionary object.  Takes a Time::Piect object, C<date>, to create the object.
@@ -159,14 +143,19 @@ sub BUILD {
     my $advent = _determineAdvent( $self->date );
     my $easter = _determineEaster( $advent->firstSunday->year + 1 );
 
-    my %commonNameInfo = _determineDay( $self->date, $self->lectionary, $self->includeFeasts, $advent, $easter );
+    my %commonNameInfo =
+      _determineDay( $self->date, $self->lectionary, $advent, $easter );
     $self->_setCommonName( $commonNameInfo{commonName} );
-    $self->_setDisplayName( _determineDisplayName( $self->lectionary, $commonNameInfo{commonName} ) );
-    $self->_setAltName( _determineAltName( $self->lectionary, $commonNameInfo{commonName} ) );
+    $self->_setDisplayName(
+        _determineDisplayName( $self->lectionary, $commonNameInfo{commonName} )
+    );
+    $self->_setAltName(
+        _determineAltName( $self->lectionary, $commonNameInfo{commonName} ) );
 
     $self->_setType( $commonNameInfo{type} );
 
-    my %multiLectInfo = _determineMultiLect( $self->lectionary, $commonNameInfo{commonName} );
+    my %multiLectInfo =
+      _determineMultiLect( $self->lectionary, $commonNameInfo{commonName} );
     $self->_setMultiLect( $multiLectInfo{multiLect} );
     $self->_setSubLects( $multiLectInfo{multiNames} );
 }
@@ -186,20 +175,24 @@ sub _determineMultiLect {
     my $lectionary;
 
     try {
-        $data_location = dist_file( 'Date-Lectionary', 'date_lectionary_xref.xml' );
+        $data_location =
+          dist_file( 'Date-Lectionary', 'date_lectionary_xref.xml' );
         $lectionary = $parser->parse_file($data_location);
     }
     catch {
-        confess "The lectionary cross reference file could not be found or parsed.";
+        confess
+          "The lectionary cross reference file could not be found or parsed.";
     };
 
     my $compiled_xpath;
 
     try {
-        $compiled_xpath = XML::LibXML::XPathExpression->new("/xref/day[\@multi=\"$commonName\"]/alt[\@type='$tradition']");
+        $compiled_xpath = XML::LibXML::XPathExpression->new(
+            "/xref/day[\@multi=\"$commonName\"]/alt[\@type='$tradition']");
     }
     catch {
-        confess "The XPATH expression to to query the cross reference database could not be compiled.";
+        confess
+"The XPATH expression to to query the cross reference database could not be compiled.";
     };
 
     my @multiNames;
@@ -217,7 +210,8 @@ sub _determineMultiLect {
         }
     }
     catch {
-        confess "An unpected error occured while querying the cross reference database.";
+        confess
+"An unpected error occured while querying the cross reference database.";
     };
 }
 
@@ -236,22 +230,28 @@ sub _determineDisplayName {
     my $lectionary;
 
     try {
-        $data_location = dist_file( 'Date-Lectionary', 'date_lectionary_xref.xml' );
+        $data_location =
+          dist_file( 'Date-Lectionary', 'date_lectionary_xref.xml' );
         $lectionary = $parser->parse_file($data_location);
     }
     catch {
-        confess "The lectionary cross reference file could not be found or parsed.";
+        confess
+          "The lectionary cross reference file could not be found or parsed.";
     };
 
     my $compiled_xpath;
     my $multi_xpath;
 
     try {
-        $compiled_xpath = XML::LibXML::XPathExpression->new("/xref/day[\@name=\"$commonName\"]/alt[\@type='$tradition']");
-        $multi_xpath    = XML::LibXML::XPathExpression->new("/xref/day[\@multi=\"$commonName\"]");
+        $compiled_xpath = XML::LibXML::XPathExpression->new(
+            "/xref/day[\@name=\"$commonName\"]/alt[\@type='$tradition']");
+        $multi_xpath =
+          XML::LibXML::XPathExpression->new(
+            "/xref/day[\@multi=\"$commonName\"]");
     }
     catch {
-        confess "The XPATH expression to to query the cross reference database could not be compiled.";
+        confess
+"The XPATH expression to to query the cross reference database could not be compiled.";
     };
 
     my $displayName;
@@ -270,7 +270,8 @@ sub _determineDisplayName {
         }
     }
     catch {
-        confess "An unpected error occured while querying the cross reference database.";
+        confess
+"An unpected error occured while querying the cross reference database.";
     };
 
 }
@@ -290,21 +291,25 @@ sub _determineAltName {
     my $lectionary;
 
     try {
-        $data_location = dist_file( 'Date-Lectionary', 'date_lectionary_xref.xml' );
+        $data_location =
+          dist_file( 'Date-Lectionary', 'date_lectionary_xref.xml' );
         $lectionary = $parser->parse_file($data_location);
     }
     catch {
-        confess "The lectionary cross reference file could not be found or parsed.";
+        confess
+          "The lectionary cross reference file could not be found or parsed.";
     };
 
     my $compiled_xpath;
     my $multi_xpath;
 
     try {
-        $compiled_xpath = XML::LibXML::XPathExpression->new("/xref/day[\@name=\"$commonName\"]/alt[\@type='$tradition-alt']");
+        $compiled_xpath = XML::LibXML::XPathExpression->new(
+            "/xref/day[\@name=\"$commonName\"]/alt[\@type='$tradition-alt']");
     }
     catch {
-        confess "The XPATH expression to to query the cross reference database could not be compiled.";
+        confess
+"The XPATH expression to to query the cross reference database could not be compiled.";
     };
 
     my $altName;
@@ -314,7 +319,8 @@ sub _determineAltName {
         return $altName;
     }
     catch {
-        confess "An unpected error occured while querying the cross reference database.";
+        confess
+"An unpected error occured while querying the cross reference database.";
     };
 
 }
@@ -335,7 +341,8 @@ sub _determineAdvent {
         return $advent;
     }
     catch {
-        confess "Could not calculate Advent for the given date [" . $date->ymd . "].";
+        confess "Could not calculate Advent for the given date ["
+          . $date->ymd . "].";
     };
 }
 
@@ -352,7 +359,8 @@ sub _determineEaster {
 
     try {
         my ( $easterMonth, $easterDay ) = easter($easterYear);
-        $easter = Time::Piece->strptime( $easterYear . "-" . $easterMonth . "-" . $easterDay, "%Y-%m-%d" );
+        $easter = Time::Piece->strptime(
+            $easterYear . "-" . $easterMonth . "-" . $easterDay, "%Y-%m-%d" );
         return $easter;
     }
     catch {
@@ -372,25 +380,29 @@ sub _determineFeasts {
 
     my $yesterday = $date - ONE_DAY;
 
-    my $yesterdayName;
     if ( $yesterday->wday == 1 ) {
-        $yesterdayName = _buildMoveableDays( $yesterday, $lectionary );
+        my $dayName = _buildMoveableDays( $yesterday, $lectionary );
+        if ($dayName) {
+            return ( commonName => $dayName, type => 'moveableFeast' );
+        }
     }
-
-    if ($yesterdayName) {
-        return ( commonName => $yesterdayName, type => 'moveableFeast' );
+    elsif ( $date->wday == 1 ) {
+        my $dayName = _buildFixedDays( $date, $lectionary );
+        if ($dayName) {
+            return ( commonName => $dayName, type => 'fixedFeast' );
+        }
     }
+    else {
+        my $dayName = _buildFixedDays( $date, $lectionary );
+        if ($dayName) {
+            return ( commonName => $dayName, type => 'fixedFeast' );
+        }
 
-    my $fixedDayName = _buildFixedDays( $date, $lectionary );
-    if ($fixedDayName) {
-        return ( commonName => $fixedDayName, type => 'fixedFeast' );
+        $dayName = _buildMoveableDays( $date, $lectionary );
+        if ($dayName) {
+            return ( commonName => $dayName, type => 'moveableFeast' );
+        }
     }
-
-    my $moveableDayName = _buildMoveableDays( $date, $lectionary );
-    if ( $moveableDayName && $date->wday != 1 ) {
-        return ( commonName => $moveableDayName, type => 'moveableFeast' );
-    }
-
     return ( commonName => undef, type => undef );
 }
 
@@ -467,7 +479,7 @@ sub _buildMoveableDays {
     #Moveable holidays in July
     elsif ( $date->mon == 7 ) {
         if ( $date->mday == 22 && $lectionary eq 'acna' ) {
-            return "St. Mary Magdalene";
+            return "St. Mary of Magdala";
         }
         if ( $date->mday == 25 && $lectionary eq 'acna' ) {
             return "St. James";
@@ -628,7 +640,8 @@ sub _determineAshWednesday {
         return $ashWednesday;
     }
     catch {
-        confess "Could not calculate Ash Wednesday for Easter [" . $easter->ymd . "].";
+        confess "Could not calculate Ash Wednesday for Easter ["
+          . $easter->ymd . "].";
     };
 }
 
@@ -649,7 +662,8 @@ sub _determineAscension {
         return $ascension;
     }
     catch {
-        confess "Could not calculate Ascension for Easter [" . $easter->ymd . "].";
+        confess "Could not calculate Ascension for Easter ["
+          . $easter->ymd . "].";
     };
 }
 
@@ -670,7 +684,8 @@ sub _determinePentecost {
         return $pentecost;
     }
     catch {
-        confess "Could not calculate Pentecost for Easter [" . $easter->ymd . "].";
+        confess "Could not calculate Pentecost for Easter ["
+          . $easter->ymd . "].";
     };
 }
 
@@ -765,29 +780,6 @@ sub _determineEasterWeek {
     return undef;
 }
 
-=head2 _hasChristmas2
-
-Private method to determine if there is a second Sunday of Christmas in the current liturgical year.  Returns 1 when there is a second Sunday of Christmas and 0 otherwise.
-
-=cut
-
-sub _hasChristmas2 {
-    my $advent   = shift;
-    my $epiphany = shift;
-
-    my $firstChristmas = nextSunday( $advent->fourthSunday );
-    my $dateMarker     = nextSunday($firstChristmas);
-
-    if ( $dateMarker < $epiphany ) {
-        return 1;
-    }
-    else {
-        return 0;
-    }
-
-    return 0;
-}
-
 =head2 _determineChristmasEpiphany
 
 Private method that matches the date given at construction against the Sundays in Christmastide and Epiphany.  Returns a string representation of the name of the Sunday in the lectionary.
@@ -801,12 +793,6 @@ sub _determineChristmasEpiphany {
 
     my $ashWednesday = shift;
 
-    my $lectionary = shift;
-
-    my $epiphany = Time::Piece->strptime( $date->year . "-01-06", "%Y-%m-%d" );
-
-    my $christmas2 = _hasChristmas2( $advent, $epiphany );
-
     #Is the date in Christmastide?
     my $dateMarker = nextSunday( $advent->fourthSunday );
     if ( $date == $dateMarker ) {
@@ -814,34 +800,57 @@ sub _determineChristmasEpiphany {
     }
 
     $dateMarker = nextSunday($dateMarker);
-    if ( $date == $dateMarker && $christmas2 == 1 ) {
+    if ( $date == $dateMarker ) {
         return "The Second Sunday of Christmas";
     }
-    elsif ( $date == $dateMarker ) {
+
+    #Is the date in Epiphany?
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
         return "The First Sunday of Epiphany";
     }
 
-    my @epiphanySundays = ( "The First Sunday of Epiphany", "The Second Sunday of Epiphany", "The Third Sunday of Epiphany", "The Fourth Sunday of Epiphany", "The Fifth Sunday of Epiphany", "The Sixth Sunday of Epiphany", "The Seventh Sunday of Epiphany", "The Last Sunday after Epiphany" );
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
+        return "The Second Sunday of Epiphany";
+    }
 
-    #Is the date in Epiphany?
-    my $sunCount = 0;
-    foreach my $sunday (@epiphanySundays) {
-        $dateMarker = nextSunday($dateMarker);
-        if ( $date == $dateMarker && $date == prevSunday($ashWednesday) ) {
-            return "The Last Sunday after Epiphany";
-        }
-        if ( $date == $dateMarker && $date == prevSunday( prevSunday($ashWednesday) ) && $lectionary eq 'acna' ) {
-            return "The Second to Last Sunday after Epiphany";
-        }
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
+        return "The Third Sunday of Epiphany";
+    }
 
-        if ( $date == $dateMarker && $christmas2 == 1 ) {
-            return $epiphanySundays[$sunCount];
-        }
-        elsif ( $date == $dateMarker && $christmas2 == 0 ) {
-            return $epiphanySundays[ $sunCount + 1 ];
-        }
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
+        return "The Fourth Sunday of Epiphany";
+    }
 
-        $sunCount++;
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
+        return "The Fifth Sunday of Epiphany";
+    }
+
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
+        return "The Sixth Sunday of Epiphany";
+    }
+
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
+        return "The Seventh Sunday of Epiphany";
+    }
+
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker && $date != prevSunday($ashWednesday) ) {
+        return "The Second to Last Sunday after Epiphany";
+    }
+    elsif ( $date == $dateMarker && $date == prevSunday($ashWednesday) ) {
+        return "The Last Sunday after Epiphany";
+    }
+
+    $dateMarker = nextSunday($dateMarker);
+    if ( $date == $dateMarker ) {
+        return "The Last Sunday after Epiphany";
     }
 
     confess "There are no further Sundays of Christmastide or Epiphany.";
@@ -943,137 +952,164 @@ sub _determineOrdinary {
         return "Trinity Sunday";
     }
 
-    my $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-05-25", "%Y-%m-%d" ) );
+    my $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-05-25", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 8";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-06-01", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-06-01", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 9";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-06-08", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-06-08", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 10";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-06-15", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-06-15", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 11";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-06-22", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-06-22", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 12";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-06-29", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-06-29", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 13";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-07-06", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-07-06", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 14";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-07-13", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-07-13", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 15";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-07-20", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-07-20", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 16";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-07-27", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-07-27", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 17";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-08-03", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-08-03", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 18";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-08-10", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-08-10", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 19";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-08-17", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-08-17", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 20";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-08-24", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-08-24", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 21";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-08-31", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-08-31", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 22";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-09-07", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-09-07", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 23";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-09-14", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-09-14", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 24";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-09-21", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-09-21", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 25";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-09-28", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-09-28", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 26";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-10-05", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-10-05", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 27";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-10-12", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-10-12", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 28";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-10-19", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-10-19", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 29";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-10-26", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-10-26", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 30";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-11-02", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-11-02", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 31";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-11-09", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-11-09", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 32";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-11-16", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-11-16", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Ordinary 33";
     }
 
-    $dateMarker = closestSunday( Time::Piece->strptime( $pentecost->year . "-11-23", "%Y-%m-%d" ) );
+    $dateMarker = closestSunday(
+        Time::Piece->strptime( $pentecost->year . "-11-23", "%Y-%m-%d" ) );
     if ( $date == $dateMarker ) {
         return "Christ the King";
     }
@@ -1088,9 +1124,8 @@ Private method that takes the Time::Piece data given at construction and, using
 =cut
 
 sub _determineDay {
-    my $date          = shift;
-    my $lectionary    = shift;
-    my $includeFeasts = shift;
+    my $date       = shift;
+    my $lectionary = shift;
 
     my $advent = shift;
     my $easter = shift;
@@ -1151,27 +1186,29 @@ sub _determineDay {
     }
 
     #Feast Day Celebrations
-    if ( $includeFeasts eq 'yes' ) {
-        my %feastDay = _determineFeasts( $date, $lectionary );
-        if ( $feastDay{commonName} ) {
-            return ( commonName => $feastDay{commonName}, type => $feastDay{type} );
-        }
+    my %feastDay = _determineFeasts( $date, $lectionary );
+    if ( $feastDay{commonName} ) {
+        return ( commonName => $feastDay{commonName}, type => $feastDay{type} );
     }
 
     #If the date isn't a Sunday and we've determined it is not a fixed holiday
     #then there are no readings for that day.
     if ( $date->wday != 1 ) {
         return (
-            commonName => $date->fullday . ', ' . $date->fullmonth . ' ' . $date->mday . ', ' . $date->year,
-            type       => 'noLect'
+            commonName => $date->fullday . ', '
+              . $date->fullmonth . ' '
+              . $date->mday . ', '
+              . $date->year,
+            type => 'noLect'
         );
     }
 
     #Sundays of the Liturgical Year
     if ( $date < $ashWednesday ) {
         return (
-            commonName => _determineChristmasEpiphany( $date, $advent, $ashWednesday, $lectionary ),
-            type       => 'Sunday'
+            commonName =>
+              _determineChristmasEpiphany( $date, $advent, $ashWednesday ),
+            type => 'Sunday'
         );
     }
 
@@ -1240,17 +1277,15 @@ L<http://search.cpan.org/dist/Date-Lectionary-Day/>
 
 Many thanks to my beautiful wife, Jennifer, and my amazing daughter, Rosemary.  But, above all, SOLI DEO GLORIA!
 
-=head1 LICENSE
+=head1 LICENSE AND COPYRIGHT
 
-Copyright 2016-2018 MICHAEL WAYNE ARNOLD
+Copyright 2016 Michael Wayne Arnold.
 
-Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
-1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
-
-2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+See L<http://dev.perl.org/licenses/> for more information.
 
 
 =cut
