@@ -4,12 +4,9 @@ use v5.22;
 use strict;
 use warnings;
 
-use Try::Tiny::Tiny;
-
 use Moose;
-use MooseX::StrictConstructor;
 use Carp;
-use Try::Catch;
+use Try::Tiny;
 use namespace::autoclean;
 use Moose::Util::TypeConstraints;
 
@@ -19,11 +16,11 @@ Date::Lectionary::Year - Cycle Year for the Lectionary
 
 =head1 VERSION
 
-Version 1.3.0
+Version 1.20161222
 
 =cut
 
-use version; our $VERSION = version->declare("v1.3.0");
+our $VERSION = '1.20161222';
 
 =head1 SYNOPSIS
 
@@ -83,11 +80,13 @@ sub _determineYear {
             return 'C';
         }
         else {
-            confess "The liturgical year for the year [" . $calYear . "] could not be determined.";
+            confess "The liturgical year for the year [" . $calYear
+              . "] could not be determined.";
         }
     }
     catch {
-        confess "A liturgical year for the value [" . $calYear . "] could not be calculated.";
+        confess "A liturgical year for the value [" . $calYear
+          . "] could not be calculated.";
     };
 }
 
@@ -134,17 +133,15 @@ L<http://search.cpan.org/dist/Date-Lectionary-Year/>
 
 Many thanks to my beautiful wife, Jennifer, and my amazing daughter, Rosemary.  But, above all, SOLI DEO GLORIA!
 
-=head1 LICENSE
+=head1 LICENSE AND COPYRIGHT
 
-Copyright 2016-2018 MICHAEL WAYNE ARNOLD
+Copyright 2016 Michael Wayne Arnold.
 
-Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
-1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
-
-2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+See L<http://dev.perl.org/licenses/> for more information.
 
 
 =cut
